'use strict';

/* For ESLint: List any global identifiers used in this file below */
/* global */

// Requires jquery.

// Lets you move up and down the DOM starting from a specific element.
function ElementChain(el) {
  this.stack = [];
  this.change_events = [];
  this.stack.push($(el));
}

ElementChain.prototype.current = function currentFunction() {
  return this.stack[this.stack.length - 1];
};

ElementChain.prototype.moveUp = function moveUpFunction() {
  if (this.current().parent().length > 0
      && this.current().parent()[0].nodeName !== 'BODY') {
    this.stack.push(this.current().parent());
    this.change();
    return true;
  }

  return false;
};

ElementChain.prototype.moveDown = function moveDownFunction() {
  if (this.stack.length > 1) {
    this.stack.pop();
    this.change();
    return true;
  }

  return false;
};
// Moves to the appropriate parent depth.  0 is the original element,
// 1 is its parent, etc.
ElementChain.prototype.moveTo = function moveToFunction(depth) {
  while (this.stack.length > depth + 1) {
    if (!this.moveDown()) {
      break;
    }
  }
  while (this.stack.length < depth + 1) {
    if (!this.moveUp()) {
      break;
    }
  }
};

ElementChain.prototype.change = function changeFunction(listener, callback) {
  if (callback) {
    this.change_events.push([listener, callback]);
  } else {
    for (let i = 0; i < this.change_events.length; i += 1) {
      const data = this.change_events[i];
      data[1].call(data[0]);
    }
  }
};

// required return value for tabs.executeScript
/* eslint-disable-next-line no-unused-expressions */
'';

// # sourceURL=/uiscripts/blacklisting/elementchain.js
